# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'digest/sha1'

module PuppetX
  module EnterpriseModules
    module Postgres
      # docs
      # rubocop: disable Naming/MethodParameterName
      module CreateOnly
        def insync?(is)
          create_only_insync?(is, should)
        end

        def update?
          resource.provider.ensure.to_s != 'absent'
        end

        def create_only?
          resource[:create_only].include?(name.to_s)
        end

        def create_only_insync?(is, should)
          if update? && create_only?
            Puppet.info "Skipping property change of #{name}, because it is on the create_only list." if is != should
            true
          else
            is.to_s == should.to_s
          end
        end
      end
      # rubocop: enable Naming/MethodParameterName
    end
  end
end
