# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module PuppetX
  module EnterpriseModules
    # All used mungers
    module Postgres
      # encoding: UTF-8
      #
      #
      # Define all common mungers available for all types
      #
      module Mungers
        #
        # Define some Postgres specific mungers
        #
        module LeaveDbRestToUppercase
          #
          # This munger extracts the db from the value and uppercases therest of the value.
          # The db remains as it is.
          #
          def unsafe_munge(original_value)
            value, _, db = original_value.partition('@')
            "#{value.upcase}@#{db}"
          end
        end

        # Upcase the property
        module Upcase
          def unsafe_munge(entry)
            fail('expects a String') unless entry.is_a?(String)

            entry.upcase
          end
        end
      end
    end
  end
end
