# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# Docs
module PuppetX
  module EnterpriseModules
    module Postgres
      # Rading the content of the settings file
      module Settings
        def settings_file
          Pathname.new('/etc/pg_register.yaml').expand_path
        end

        def self.included(parent)
          parent.extend(Settings)
        end

        def configuration_for(key)
          fail "No instance configuration found for #{key}." unless configuration.key?(key)

          configuration[key]
        end

        def configuration_value_for(db, value, default_value = '')
          configuration_for(db).fetch(value) { default_value }
        end

        def configuration
          @configuration = read_from_yaml
        end

        # rubocop: disable Security/Open
        def read_from_yaml
          if File.exist?(settings_file)
            open(settings_file) { |f| Puppet::Util::Yaml.safe_load(f, [Symbol]) }
          else
            {}
          end
        end
        # rubocop: enable Security/Open

        def registered_instances
          if configuration.is_a?(Hash)
            configuration.keys
          else
            []
          end
        end
      end
    end
  end
end
