# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'tempfile'
require 'fileutils'
require 'puppet_x/enterprisemodules/postgres/psql_command'

module PuppetX
  module EnterpriseModules
    module Postgres
      # docs
      class Sql
        attr_reader :instance, :db, :username, :password, :os_user, :timeout

        def initialize(options = {})
          @command    = PsqlCommand.new(options)
          @instance   = @command.instance
          @db         = @command.db
          @os_user    = @command.os_user
          @db_user    = @command.db_user
          @username   = @command.username
          @password   = @command.password
          @timeout    = @command.timeout
        end

        def execute(command)
          create_output_file
          @command.execute_sql_command(command, @output_file.path)
        end

        private

        def create_output_file
          @output_file = Tempfile.new(['output', '.csv'])
          @output_file.close
          FileUtils.chown(@os_user, nil, @output_file.path)
          FileUtils.chmod(0o600, @output_file.path)
        end
      end
    end
  end
end
